
clear all
tic
%MORISAL water absorption coefficient computation for CEM I (slow
%absorbing)
%Code will compute WAC as the intersection of two absorption curves.
%absorption curves are found using Linear regression
%Read data
Data=readtable('WAC_initial drying.xlsx','sheet','CEMI-WAC test','range','A18:M30');
A=readtable('WAC_initial drying.xlsx','sheet','CEMI-WAC test','range','Q17:AB18');
%md=readtable('WAC_initial drying.xlsx','sheet','NHL-WAC test','range','Q1:AB2');
AA=table2array(A);
%AA=(ones(1,12));
[Control, Control_WAC]=computeWAC(Data.T,Data(:,2:5),AA(1:4)); %control
[P1, P1_WAC]=computeWAC(Data.T,Data(:,6:9),AA(5:8)); % 0.1% samples
[P2, P2_WAC]=computeWAC(Data.T,Data(:,10:13),AA(9:12)); %1% samples
WAC_CEMI=[Control_WAC, P1_WAC, P2_WAC];

%%
%Plot
f=figure;
errorbar(sqrt(Data.T),Control(:,1),Control(:,2), 'r^-','MarkerFaceColor','r','LineWidth',1.2);
hold on
errorbar(sqrt(Data.T),P1(:,1),P1(:,2), 'g^-','MarkerFaceColor','g','LineWidth',1.2);
errorbar(sqrt(Data.T),P2(:,1),P2(:,2), 'b^-','MarkerFaceColor','b','LineWidth',1.2);

%Intersection
scatter(Control_WAC(1),Control_WAC(2),100,'rx');
scatter(P1_WAC(1),P1_WAC(2),100,'gx');
scatter(P2_WAC(1),P2_WAC(2),100,'bx');
grid on
xlabel('\surdt [min^{0.5}]','Interpreter','tex');
ylabel('W/M_0 [g/g.m^2]')
legend('Control','0.1 % FeCN','1% FeCN','location','southeast','FontSize',16);
title('CEMI');
set(gca,'FontSize',16);
exportgraphics(f,'CEM_WAC_Mo.pdf');

WAC_final=WAC_CEMI(2,:)./(WAC_CEMI(1,:)*sqrt(60)); %min^05 converted to s^0.5
toc



function [ct,WAC]=computeWAC(Time,D,Area) 
%Time= time vector in t^0.5 m, D=Data for computation, A=Surface area vector in m2]
D_array=(table2array(D))./Area;
M=mean(D_array,2);
s=std(D_array,0,2);
t=[ones(size(Time,1),1) sqrt(Time)];
B1=t(1:9,:)\M(1:9,:); %Linear regression stage 1
B2=t(10:end,:)\M(10:end,:); %Linear regression stage 2
%Solve equations obtained from linear regressions to find intersection
B=[-B1(2) 1; -B2(2) 1]; %coefficient matrix X
B0=[B1(1); B2(1)]; %Coefficient Matrix Intercept
WAC=B\B0; %Solve for intersection point [t,W]
ct=[M,s]; %Return for errorbars
end





