
clear all
tic
%MORISAL water absorption coefficient computation
%Code will compute WAC as the intersection of two absorption curves.
%absorption curves are found using Linear regression
%Read data

Data=readtable('WAC_initial drying.xlsx','sheet','NHL_WAC test','range','A14:M23'); %mi-md
%Data=readtable('WAC_initial drying.xlsx','sheet','NHL_WAC test','range','A2:M11');%MI
A=readtable('WAC_initial drying.xlsx','sheet','NHL_WAC test','range','Q13:AB14');
md=readtable('WAC_initial drying.xlsx','sheet','NHL_WAC test','range','Q1:AB2'); %dry weight
AA=table2array(A);
md_ar=table2array(md);
%md_mean=[mean(md_ar(1:4)) mean(md_ar(5:8)) mean(md_ar(8:12))] ; %mean for each concentration
%AA=(ones(1,12));
[Control, Control_WAC,Control_WAC_final]=computeWAC(Data.T,Data(:,2:5),AA(1:4),md_ar(1:4)); %control
[P1, P1_WAC, P1_WAC_final]=computeWAC(Data.T,Data(:,6:9),AA(5:8),md_ar(5:8)); % 0.1% samples
[P2, P2_WAC, P2_WAC_final]=computeWAC(Data.T,Data(:,10:13),AA(9:12),md_ar(9:12)); %1% samples
WAC_NHL=[Control_WAC P1_WAC P2_WAC];

%%
%Plot
f=figure;
errorbar(sqrt(Data.T),Control(:,1),Control(:,2), 'r^-','MarkerFaceColor','r','LineWidth',1.2);
hold on
errorbar(sqrt(Data.T),P1(:,1),P1(:,2), 'g^-','MarkerFaceColor','g','LineWidth',1.2);
errorbar(sqrt(Data.T),P2(:,1),P2(:,2), 'b^-','MarkerFaceColor','b','LineWidth',1.2);

%Intersection
scatter(Control_WAC(1),Control_WAC(2),100,'rx');
scatter(P1_WAC(1),P1_WAC(2),100,'gx');
scatter(P2_WAC(1),P2_WAC(2),100,'bx');
grid on
xlabel('\surdt [min^{0.5}]','Interpreter','tex');
ylabel('W/M_0 [g/g.m^2]')
legend('Control','0.1 % FeCN','1% FeCN','location','southeast','FontSize',16);
title('NHL 3.5');
set(gca,'FontSize',16);
exportgraphics(f,'NHL_WAC_area.pdf');
%%
WAC_final=(WAC_NHL(2,:))./(WAC_NHL(1,:)*sqrt(60)); %min^05 converted to s^0.5
toc


function [ct,WAC,WAC_final]=computeWAC(Time,D,Area,dry_mass) 
%Time= time vector in t^0.5 m, D=Data for computation is already mi-md, A=Surface area vector in m2]

D_array=(table2array(D))./Area;
M=mean(D_array,2);
s=std(D_array,0,2);
t=[ones(size(Time,1),1) sqrt(Time)]; 
B1=t(1:5,:)\M(1:5,:); %Linear regression stage 1
B2=t(6:end,:)\M(6:end,:); %Linear regression stage 2
%Solve equations obtained from linear regressions to find intersection
B=[-B1(2) 1; -B2(2) 1]; %coefficient matrix X
B0=[B1(1); B2(1)]; %Coefficient Matrix Intercept
WAC=B\B0; %Solve for intersection point [t,W]

%Calculation of the water absorpition coefficient as per the standard
md=mean(dry_mass./Area); %dry mass normalised to wetting area
WAC_final=1; %in g/m2/s^0.5
%WAC_final=(WAC(2,:)./(WAC(1,:)*sqrt(60)); %in g/m2/s^0.5
ct=[M,s]; %Return
end





